@@ -1,5 +1,5 @@
 package Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes;
-$Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes::VERSION = '0.0.14';
+$Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes::VERSION = '0.0.15';
 # ABSTRACT: Generate valid CPAN::Changes Changelogs from git
 
 use v5.10.1;
@@ -116,7 +116,7 @@ sub _build__last_release {
     my $self = shift;
 
     my @releases = $self->_changes->releases;
-    if (scalar @releases > 0) {
+    if (scalar @releases > 1) {
         my $last_release = version->parse($releases[-1]->version);
         $self->logger->log("Last release in changelog: $last_release");
 
@@ -377,7 +377,8 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Ioan Rogers Alexandr Bhadoria Ciornii Jakob Shantanu Voss
+=for :stopwords Ioan Rogers Alexandr Bell Bhadoria Ciornii Doug Jakob Jormola Shantanu
+Tuomas Voss
 
 =head1 NAME
 
@@ -385,7 +386,7 @@ Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes - Generate valid CPAN::Chan
 
 =head1 VERSION
 
-version 0.0.14
+version 0.0.15
 
 =head1 SYNOPSIS
 
@@ -481,7 +482,7 @@ Ioan Rogers <ioanr@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ioan Rogers.
+This software is copyright (c) 2015 by Ioan Rogers.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
